@@ -1,7 +1,7 @@
 package App::CreateSparseFile;
 
-our $DATE = '2015-11-20'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-03-21'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -136,7 +136,7 @@ App::CreateSparseFile - Create sparse file
 
 =head1 VERSION
 
-This document describes version 0.06 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2015-11-20.
+This document describes version 0.07 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2017-03-21.
 
 =head1 SYNOPSIS
 
@@ -145,17 +145,23 @@ See L<create-sparse-file>.
 =head1 FUNCTIONS
 
 
-=head2 create_sparse_file(%args) -> [status, msg, result, meta]
+=head2 create_sparse_file
+
+Usage:
+
+ create_sparse_file(%args) -> [status, msg, result, meta]
 
 Create sparse file.
 
 Examples:
 
+=over
+
+=item * Create a sparse file called file.bin with size of 30GB:
+
  create_sparse_file( name => "file.bin", size => "30G");
 
-
-Create a sparse file called file.bin with size of 30GB.
-
+=back
 
 Sparse file is a file with a predefined size (sometimes large) but does not yet
 allocate all its (blank) data on disk. Sparse file is a feature of filesystem.
@@ -164,7 +170,7 @@ I usually create sparse file when I want to create a large disk image but do not
 want to preallocate its data yet. Creating a sparse file should be virtually
 instantaneous.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -225,7 +231,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
